/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    $RCSfile: itkConstShapedValuedNeighborhoodIterator.h,v $
  Language:  C++
  Date:      $Date: 2008-10-07 12:04:18 $
  Version:   $Revision: 1.15 $

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#ifndef __itkConstShapedValuedNeighborhoodIterator_h
#define __itkConstShapedValuedNeighborhoodIterator_h

#include "itkConstShapedNeighborhoodIterator.h"

namespace itk 
{

/** \class ConstShapedValuedNeighborhoodIterator
 *
 * \brief A Shaped Iterator with values associated to every neighbor.
 *
 * \sa ImageConstIteratorWithIndex */
template<class TImage,  class TBoundaryCondition
                       = ZeroFluxNeumannBoundaryCondition<TImage> >
class ITK_EXPORT ConstShapedValuedNeighborhoodIterator
  :  public ConstShapedNeighborhoodIterator<TImage, TBoundaryCondition>
{
public:

  /** Extract image type information. */
  typedef typename TImage::InternalPixelType InternalPixelType;
  typedef typename TImage::PixelType         PixelType;
    
  /** Save the image dimension. */
  itkStaticConstMacro(Dimension, unsigned int, TImage::ImageDimension);
  
  /** Standard class typedefs. */
  typedef ConstShapedValuedNeighborhoodIterator                       Self;
  typedef ConstShapedNeighborhoodIterator<TImage, TBoundaryCondition> Superclass;

  virtual void SetPixelWeight( unsigned int neighborhId, PixelType value);
  virtual PixelType GetPixelWeight( unsigned int neighborhId ) const;

  typedef typename Superclass::SizeType       SizeType;
  typedef typename Superclass::RegionType     RegionType;
  typedef typename Superclass::ImageType      ImageType;

  /** Constructor which establishes the region size, neighborhood, and image
   * over which to walk. */
  ConstShapedValuedNeighborhoodIterator(const SizeType &radius,
                       const ImageType * ptr,
                       const RegionType &region) 
                   : Superclass (radius, const_cast<ImageType*>(ptr), region)
    {}

  /** Default constructor */
  ConstShapedValuedNeighborhoodIterator()
    {
    }

  /** Virtual destructor */
  virtual ~ConstShapedValuedNeighborhoodIterator()  { }

  unsigned int Size() const
    {
    return this->m_PixelWeights.size();
    }

protected:
  /** Copy constructor */
  ConstShapedValuedNeighborhoodIterator( const ConstShapedValuedNeighborhoodIterator & );
  // purposely not implemented

  /** Standard itk print method */
  virtual void PrintSelf(std::ostream &, Indent) const;

  /** An stl storage container type that can be sorted.  The type used for
   *  the list of pixel values in the active pixels of the neighborhood. */
  typedef std::vector<PixelType> PixelListType;

  PixelListType    m_PixelWeights;
};


} // namespace itk


#ifndef ITK_MANUAL_INSTANTIATION
#include "itkConstShapedValuedNeighborhoodIterator.txx"
#endif

#endif
