/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    $RCSfile: itkConstShapedValuedNeighborhoodIterator.txx,v $
  Language:  C++
  Date:      $Date: 2006-04-22 15:34:44 $
  Version:   $Revision: 1.9 $

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#ifndef __itkConstShapedValuedNeighborhoodIterator_txx
#define __itkConstShapedValuedNeighborhoodIterator_txx
#include "itkConstShapedValuedNeighborhoodIterator.h"
namespace itk {
 
template<class TImage, class TBoundaryCondition>
void
ConstShapedValuedNeighborhoodIterator<TImage, TBoundaryCondition>
::SetPixelWeight( unsigned int neighborhId, PixelType value )
{
  const unsigned int numberOfActiveNeigbors = this->GetActiveIndexList().size();
 
  if( this->m_PixelWeights.size() != numberOfActiveNeigbors )
    {
    this->m_PixelWeights.resize( numberOfActiveNeigbors );
    }

  if( neighborhId < numberOfActiveNeigbors )
    {
    this->m_PixelWeights[neighborhId] = value;
    }
  else
    {
    itkGenericExceptionMacro("Attempting to set a pixel value to neighbor out of range");
    }
}
 
template<class TImage, class TBoundaryCondition>
typename ConstShapedValuedNeighborhoodIterator<TImage, TBoundaryCondition>::PixelType
ConstShapedValuedNeighborhoodIterator<TImage, TBoundaryCondition>
::GetPixelWeight( unsigned int neighborhId ) const
{
  return this->m_PixelWeights[neighborhId];
}

template<class TImage, class TBoundaryCondition>
void
ConstShapedValuedNeighborhoodIterator<TImage, TBoundaryCondition>
::PrintSelf(std::ostream &os, Indent indent) const
{
  os << indent <<  "ConstShapedValuedNeighborhoodIterator {this = " << this;
  os << " m_PixelWeights = [";
  typename PixelListType::const_iterator it = m_PixelWeights.begin();
  while( it != m_PixelWeights.end() )
    {
    os << *it << " ";
    ++it;
    }
  os << "] ";
  os << "}" << std::endl;
  Superclass::PrintSelf(os, indent.GetNextIndent());
}

} // namespace itk

#endif
