/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    $RCSfile: itkMarchingCubesImageToMeshFilterTest1.cxx,v $
  Language:  C++
  Date:      $Date: 2008-11-21 20:00:48 $
  Version:   $Revision: 1.8 $

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#if defined(_MSC_VER)
#pragma warning ( disable : 4786 )
#endif

#include "itkImageFileReader.h" 
#include "itkImageFileWriter.h" 
#include "itkHitOrMissImageFilter.h"
#include "itkImage.h"


int main( int argc, char * argv[] )
{
  
  if( argc < 3 )
    {
    std::cerr << "Missing Parameters " << std::endl;
    std::cerr << "Usage: " << argv[0];
    std::cerr << " inputImage outputImage";
    return EXIT_FAILURE;
    }
  
  typedef   signed short   ImagePixelType;
  const     unsigned int   ImageDimension = 3;

  typedef   itk::Image< ImagePixelType, ImageDimension >   ImageType;

  typedef   itk::HitOrMissImageFilter< ImageType, ImageType > FilterType;

  typedef   itk::ImageFileReader< ImageType  >        ReaderType;
  typedef   itk::ImageFileWriter< ImageType  >        WriterType;

  ReaderType::Pointer reader = ReaderType::New();
  reader->SetFileName( argv[1] );

  try
    {
    reader->Update();
    }
  catch( itk::ExceptionObject & excp )
    {
    std::cerr << excp << std::endl;
    return EXIT_FAILURE;
    }

  FilterType::Pointer filter = FilterType::New();

  filter->SetInput( reader->GetOutput() );

  WriterType::Pointer writer = WriterType::New();
  writer->SetInput( filter->GetOutput() );
  writer->SetFileName( argv[2] );

  try
    {
    writer->Write();
    }
  catch( itk::ExceptionObject & excp )
    {
    std::cerr << "Exception thrown " << std::endl;
    std::cerr << excp << std::endl;
    return EXIT_FAILURE;
    }

  return EXIT_SUCCESS;
}
